==> basicdsp-1.0.tgz: basicdsp-1.0/aboutdialog.cpp <==
/********************************************************************
  BasicDSP
  Copyright 2006-2007 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#include <wx/wx.h>
#include "aboutdialog.h"
#include "gui.h"
#include "basicdsp_splash.xpm"
#include <wx/imagxpm.h>

BEGIN_EVENT_TABLE(AboutDialog, wxDialog)
END_EVENT_TABLE()

AboutDialog::AboutDialog(wxWindow *parent, wxWindowID id, const wxString &title,
	              const wxPoint &pos,
	              const wxSize &size,
	              long style) 
                : wxDialog(parent, id, title, pos, size, style),
                splash_bitmap(NULL), splash_xpm(NULL)
{
  if (wxImage::FindHandler(wxBITMAP_TYPE_XPM)==NULL) 
    wxImage::AddHandler(new wxXPMHandler); // add the XPM handler if not found!

  // total mess with multiple passes..
  // to clean this up would mean patching wxWidgets :(
  splash_xpm = new wxImage(basicdsp_splash_xpm);
  if (splash_xpm != NULL) 
    splash_bitmap = new wxBitmap(splash_xpm);

  if ((splash_bitmap!=NULL) && (splash_bitmap->Ok()))
  {
     wxBoxSizer *topsizer = new wxBoxSizer(wxVERTICAL);
     wxColour backgroundcolour = wxColour(85,110,126);

     staticbitmap = new wxStaticBitmap(this, -1, *splash_bitmap, wxPoint(0,0), wxDefaultSize ,wxBORDER_NONE);

     SetBackgroundColour(backgroundcolour);
     topsizer->Add(staticbitmap, 1, wxALL, 0);

     wxStaticText *text = new wxStaticText(this, -1, APPNAME _T(" version ") VERSION );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     text = new wxStaticText(this, -1, 
        _T("Copyright 2006-2007\nThis program may be freely copied under GPLv2.\n")
        _T("Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org\n")
        _T("Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl")
        );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     text = new wxStaticText(this, -1, 
        _T("http://wwwhome.cs.utwente.nl/~ptdeboer/ham/basicdsp/\n")
        _T("http://home.tiscali.nl/curious_about/PE1OIT/")
        );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     SetSizer(topsizer);
     topsizer->SetSizeHints(this);

     Refresh();
  }
    
  if (splash_xpm!=NULL) delete splash_xpm;
  if (splash_bitmap!=NULL) delete splash_bitmap;
}

AboutDialog::~AboutDialog()
{
}

==> basicdsp-1.01.tgz: basicdsp-1.01/aboutdialog.cpp <==
/********************************************************************
  BasicDSP
  Copyright 2006-2008 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#include <wx/wx.h>
#include "aboutdialog.h"
#include "gui.h"
#include "basicdsp_splash.xpm"
#include <wx/imagxpm.h>

BEGIN_EVENT_TABLE(AboutDialog, wxDialog)
END_EVENT_TABLE()

AboutDialog::AboutDialog(wxWindow *parent, wxWindowID id, const wxString &title,
	              const wxPoint &pos,
	              const wxSize &size,
	              long style) 
                : wxDialog(parent, id, title, pos, size, style),
                splash_bitmap(NULL), splash_xpm(NULL)
{
  if (wxImage::FindHandler(wxBITMAP_TYPE_XPM)==NULL) 
    wxImage::AddHandler(new wxXPMHandler); // add the XPM handler if not found!

  // total mess with multiple passes..
  // to clean this up would mean patching wxWidgets :(
  splash_bitmap = new wxBitmap(basicdsp_splash_xpm);

  if ((splash_bitmap!=NULL) && (splash_bitmap->Ok()))
  {
     wxBoxSizer *topsizer = new wxBoxSizer(wxVERTICAL);
     wxColour backgroundcolour = wxColour(85,110,126);

     staticbitmap = new wxStaticBitmap(this, -1, *splash_bitmap, wxPoint(0,0), wxDefaultSize ,wxBORDER_NONE);

     SetBackgroundColour(backgroundcolour);
     topsizer->Add(staticbitmap, 1, wxALL, 0);

     wxStaticText *text = new wxStaticText(this, -1, APPNAME _T(" version ") VERSION );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     text = new wxStaticText(this, -1, 
        _T("Copyright 2006-2008\nThis program may be freely copied under GPLv2.\n")
        _T("Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org\n")
        _T("Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl")
        );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     text = new wxStaticText(this, -1, 
        _T("http://wwwhome.cs.utwente.nl/~ptdeboer/ham/basicdsp/\n")
        _T("http://home.tiscali.nl/curious_about/PE1OIT/")
        );
        text->SetForegroundColour(wxColour(_T("white")));
        text->SetBackgroundColour(backgroundcolour);
        topsizer->Add(text, 0, wxALL, 4);

     SetSizer(topsizer);
     topsizer->SetSizeHints(this);

     Refresh();
  }
    
  if (splash_xpm!=NULL) delete splash_xpm;
  if (splash_bitmap!=NULL) delete splash_bitmap;
}

AboutDialog::~AboutDialog()
{
}
